@@ -1,13 +1,13 @@
 """This module process data from ~/.fgo folder."""
 
 import os
-import sys
 import gzip
 import gettext
 import codecs
 import traceback
 from Tkinter import IntVar, StringVar
 from tkMessageBox import showerror
+import tkFont
 
 from gui.infowindow import InfoWindow
 from constants import *
@@ -61,31 +61,87 @@ class Config:
         self.TS_port = StringVar()
         self.TS_scenery = StringVar()
         self.window_geometry = StringVar()
+        self.baseFontSize = StringVar()
+        self.TkDefaultFontSize = IntVar()
 
-        self.keywords = {'--aircraft='       : self.aircraft,
-                         '--airport='        : self.airport,
-                         '--fg-root='        : self.FG_root,
-                         '--fg-scenery='     : self.FG_scenery,
-                         '--carrier='        : self.carrier,
-                         '--parkpos='        : self.park,
-                         '--runway='         : self.rwy,
-                         'AI_SCENARIOS='     : self.scenario,
-                         'APT_DATA_SOURCE='  : self.apt_data_source,
-                         'AUTO_UPDATE_APT='  : self.auto_update_apt,
-                         'FG_BIN='           : self.FG_bin,
-                         'FG_AIRCRAFT='      : self.FG_aircraft,
-                         'FG_WORKING_DIR='   : self.FG_working_dir,
-                         'FILTER_APT_LIST='  : self.filtredAptList,
-                         'LANG='             : self.language,
-                         'TERRASYNC='        : self.TS,
-                         'TERRASYNC_BIN='    : self.TS_bin,
-                         'TERRASYNC_PORT='   : self.TS_port,
+        self.keywords = {'--aircraft=': self.aircraft,
+                         '--airport=': self.airport,
+                         '--fg-root=': self.FG_root,
+                         '--fg-scenery=': self.FG_scenery,
+                         '--carrier=': self.carrier,
+                         '--parkpos=': self.park,
+                         '--runway=': self.rwy,
+                         'AI_SCENARIOS=': self.scenario,
+                         'APT_DATA_SOURCE=': self.apt_data_source,
+                         'AUTO_UPDATE_APT=': self.auto_update_apt,
+                         'FG_BIN=': self.FG_bin,
+                         'FG_AIRCRAFT=': self.FG_aircraft,
+                         'FG_WORKING_DIR=': self.FG_working_dir,
+                         'FILTER_APT_LIST=': self.filtredAptList,
+                         'LANG=': self.language,
+                         'TERRASYNC=': self.TS,
+                         'TERRASYNC_BIN=': self.TS_bin,
+                         'TERRASYNC_PORT=': self.TS_port,
                          'TERRASYNC_SCENERY=': self.TS_scenery,
-                         'WINDOW_GEOMETRY='  : self.window_geometry}
+                         'WINDOW_GEOMETRY=': self.window_geometry,
+                         'BASE_FONT_SIZE=': self.baseFontSize}
 
         self._createConfDirectory()
         self.update(first_run=True)
 
+        self.setTkDefaultFontSize()
+        self.setupFonts(init=True)
+
+    def setTkDefaultFontSize(self):
+        """Save unaltered TkDefaultFont size."""
+        size = tkFont.nametofont("TkDefaultFont").actual()["size"]
+        self.TkDefaultFontSize.set(size)
+
+    def setupFonts(self, init=False):
+        """Setup the default fonts.
+
+        When called with init=True, custom fonts are created and
+        stored as attributes of self. Otherwise, they are simply
+        configured.
+
+        """
+        # According to <http://www.tcl.tk/man/tcl8.4/TkCmd/font.htm>, font
+        # sizes are interpreted this way:
+        #   - for positive values, the unit is points;
+        #   - for negative values, the unit is pixels;
+        #   - 0 is a special value for "a platform-dependent default size".
+        #
+        # Apparently, Tkinter doesn't accept floats for the 'size' parameter of
+        # <font>.configure(), even when positive (tested with Python 2.7.3).
+        baseSize = int(float(self.baseFontSize.get()))
+        # Get the actual size when baseSize == 0, otherwise scaling won't work
+        # since 0*factor == 0, regardless of the (finite) factor.
+        if baseSize == 0:
+            baseSize = self.TkDefaultFontSize.get()
+
+        def scale(factor):
+            return int(round(baseSize * factor))
+
+        def configFontSize(style, factor):
+            font = tkFont.nametofont("Tk%sFont" % style)
+            font.configure(size=scale(factor))
+
+        # Configure built-in fonts
+        for style in ("Default", "Text", "Fixed", "Caption", "Tooltip"):
+            configFontSize(style, 1)
+
+        for style, factor in (("Menu", 20 / 18.), ("Heading", 20 / 18.),
+                              ("SmallCaption", 16 / 18.), ("Icon", 14 / 18.)):
+            configFontSize(style, factor)
+
+        # Create or configure custom fonts, depending on 'init'
+        aboutTitleFontSize = scale(42 / 18.)
+        if init:
+            self.aboutTitleFont = tkFont.Font(
+                family="Helvetica", weight="bold", size=aboutTitleFontSize)
+        else:
+            self.aboutTitleFont.configure(size=aboutTitleFontSize)
+
     def makeInstalledAptList(self):
         airports = self._findInstalledApt()
 
@@ -174,6 +230,7 @@ class Config:
         self.FG_scenery.set('')
         self.FG_working_dir.set('')
         self.language.set('')
+        self.baseFontSize.set(DEFAULT_BASE_FONT_SIZE)
         self.park.set('None')
         self.rwy.set('Default')
         self.scenario.set('')
@@ -223,7 +280,7 @@ class Config:
         if self.auto_update_apt.get() and os.path.exists(self.apt_path):
             self._autoUpdateApt()
         self.airport_icao, self.airport_name, self.airport_rwy = \
-                                                                self._readApt()
+            self._readApt()
 
     def write(self, text, path=None):
         """Write options to a file.
@@ -352,7 +409,8 @@ class Config:
         if not os.path.exists(path):
             # Find currently used language.
             try:
-                lang_code = gettext.translation(MESSAGES, LOCALE_DIR).info()['language']
+                lang_code = gettext.translation(
+                    MESSAGES, LOCALE_DIR).info()['language']
             except IOError:
                 lang_code = 'en'
             path = os.path.join(DEFAULT_CONFIG_DIR, 'config_' + lang_code)
@@ -384,35 +442,38 @@ class Config:
     def _readAircraft(self):
         """Walk through Aircraft directories and return two sorted lists:
         list of aircraft names and list of paths to them."""
-        try:
-            n, p = [], []
-            for dir_ in self.aircraft_dirs:
-                if os.path.isdir(dir_):
-                    self._readAircraftData(dir_, dir_, n)
-                    for d in os.listdir(dir_):
-                        self._readAircraftData(dir_, d, n)
-            n.sort()
+        n, p = [], []
+        for dir_ in self.aircraft_dirs:
+            if os.path.isdir(dir_):
+                self._readAircraftData(dir_, dir_, n)
+                for d in os.listdir(dir_):
+                    self._readAircraftData(dir_, d, n)
+        n.sort()
 
-            for i in range(len(n)):
-                p.append(n[i][2])
-                n[i] = n[i][1]
+        for i in range(len(n)):
+            p.append(n[i][2])
+            n[i] = n[i][1]
 
-            return n, p
-
-        except OSError:
-            return [''], []
+        return n, p
 
     def _readAircraftData(self, dir_, d, n):
         path = os.path.join(dir_, d)
         if os.path.isdir(path):
-            for f in os.listdir(path):
-                if f.endswith('-set.xml'):
-                    # Dirty and ugly hack to prevent carrier-set.xml in
-                    # seahawk directory to be attached to the aircraft list.
-                    if (not path.startswith('seahawk') and 
-                        f != 'carrier-set.xml'):
-                        name = f[:-8]
-                        n.append([name.lower(), name, path])
+            try:
+                for f in os.listdir(path):
+                    self._appendAircraft(f, n, path)
+            except OSError:
+                pass
+
+    def _appendAircraft(self, f, n, path):
+        if f.endswith('-set.xml'):
+            # Dirty and ugly hack to prevent carrier-set.xml in
+            # seahawk directory to be attached to the aircraft
+            # list.
+            if (not path.startswith('seahawk') and
+                    f != 'carrier-set.xml'):
+                name = f[:-8]
+                n.append([name.lower(), name, path])
 
     def _readAircraftDirs(self):
         return self.FG_aircraft.get().split(':')
@@ -605,7 +666,7 @@ class _ProcessApt:
         message = _('Generating airport database,\nthis can take a while...')
         if head:
             message = '\n'.join((head, message))
-        self.window = InfoWindow(self.master, message, 'Helvetica 12')
+        self.window = InfoWindow(self.master, message)
         self.window.update()
 
     def makeApt(self):
@@ -623,7 +684,7 @@ class _ProcessApt:
 
     def get_apt_version_number(self):
         """Return version number of apt.dat.gz file.
-        
+
         It can be found at the beginning of a second line of the header.
 
         """
@@ -641,8 +702,8 @@ class _ProcessApt:
             raise AptdatHeaderError
 
     def get_version_number(self, origin, number, version):
-        if ((origin == 'A' or origin == 'I') and 
-            number.isdigit() and version == 'Version'):
+        if ((origin == 'A' or origin == 'I') and
+                number.isdigit() and version == 'Version'):
             return number
         else:
             raise AptdatHeaderError
@@ -658,7 +719,6 @@ class _ProcessApt:
                 self.process_airport_data(version, e)
                 self.finalize_processing_airport(line)
 
-
     def process_airport_data(self, version, e):
         if int(version) < 850:
             self.process_data_v810(e)
@@ -682,7 +742,7 @@ class _ProcessApt:
 
     def set_rwy_data(self, rwy, lat, lon, addotherend=False):
         """Set runway data.
-        
+
         If addotherend is set to True, it computes and adds 
         other end of given rwy. It is needed for apt.dat v 810 
         and earlier data format, where only one runway end is provided.
@@ -751,7 +811,7 @@ class _ProcessApt:
 
     def set_first_rwy_v850(self, e):
         self.set_rwy_data(e[8], e[9], e[10])
-        
+
     def set_second_rwy_v850(self, e):
         self.set_rwy_data(e[17], e[18], e[19])
 
