@@ -5,11 +5,12 @@ from string import punctuation
 
 from Tkinter import Toplevel, Label
 
+import tkFont
 
 class InfoWindow(Toplevel):
 
-    def __init__(self, master=None, text=None, font='Helvetica 16',  
-                 cnf={}, **kw):
+    def __init__(self, master=None, text=None,
+                 font=tkFont.nametofont("TkHeadingFont"), cnf={}, **kw):
         Toplevel.__init__(self, master, cnf, **kw)
         self._window(master, text, font)
 
