@@ -10,6 +10,7 @@ from Tkinter import *
 import tkFileDialog as fd
 from ScrolledText import ScrolledText
 from xml.etree.ElementTree import ElementTree
+from tkMessageBox import showerror
 
 try:
     from PIL import Image, ImageTk
@@ -110,14 +111,14 @@ class App:
         self.frame2.pack(side='left', fill='both')
         # Aircraft
         self.frame21 = Frame(self.frame2, borderwidth=4)
-        self.frame21.pack(side='top')
+        self.frame21.pack(side='top', expand=True)
 
         self.aircraftLabel = Label(self.frame21,
                                    textvariable=self.config.aircraft)
         self.aircraftLabel.pack(side='top')
 
         self.thumbnail = Label(self.frame21, width=171, height=128)
-        self.thumbnail.pack(side='top')
+        self.thumbnail.pack(side='top', fill='y')
         self.updateImage()
         # Airport, rwy and parking
         self.frame22 = Frame(self.frame2, borderwidth=4)
@@ -259,8 +260,10 @@ class App:
         if _('Translation:') == 'Translation:':
             translator = ''
         else:
-            translator = '\n\n\n' + _('Translation:')
-        about_text = COPYRIGHT + translator
+            translator = '\n\n' + _('Translation:')
+        authors = _('Authors:')
+        about_text = '{0}\n\n{1}\n{2}{3}'.format(COPYRIGHT, authors, AUTHORS,
+                                                 translator)
 
         self.aboutWindow = Toplevel(borderwidth=4)
         self.aboutWindow.title(_('About'))
@@ -268,8 +271,8 @@ class App:
         self.aboutWindow.transient(self.master)
         self.aboutWindow.bind('<Escape>', self._destroyAboutWindow)
 
-        self.aboutTitle = Label(self.aboutWindow, font='Helvetica 28 bold',
-                                text=NAME)
+        self.aboutTitle = Label(self.aboutWindow,
+                                font=self.config.aboutTitleFont, text=NAME)
         self.aboutTitle.pack()
         self.aboutFrame1 = Frame(self.aboutWindow, borderwidth=1,
                                  relief='sunken', padx=8, pady=12)
@@ -815,27 +818,11 @@ class App:
             self.runFGErrorMessage()
 
     def runFGErrorMessage(self):
-        self.error_message = Toplevel(borderwidth=12)
-        self.error_message.transient(self.master)
-        self.error_message.title(_('Error'))
-        self.error_message.resizable(False, False)
-        self.error_message.bind('<Escape>', self.runFGErrorMessageClose)
-
-        title = Label(self.error_message, font=('Helvetica', 18, 'bold'),
-                      text=_('Unable to run FlightGear!'))
-        title.pack(fill='x')
-
-        msg = Label(self.error_message, text=_('Please make sure that paths: '
-        'FG_BIN and FG_ROOT\nin "Preferences" window are '
-        'pointing to right directories.') + '\n')
-        msg.pack(fill='x')
-
-        button = Button(self.error_message, text=_('Close'),
-                        command=self.error_message.destroy)
-        button.pack()
-
-    def runFGErrorMessageClose(self, event=None):
-        self.error_message.destroy()
+        title = _('Unable to run FlightGear!')
+        msg = _('Please make sure that paths: FG_BIN and FG_ROOT\n'
+                'in "Preferences" window are pointing to right directories.')
+        message = '{0}\n\n{1}'.format(title, msg)
+        self.error_message = showerror(_('Error'), message)
 
     def runTS(self):
         if self.config.TS_port.get()\
@@ -987,11 +974,13 @@ class App:
         if language:
             lang_code = language
         else:
-            lang_code = translation(MESSAGES, LOCALE_DIR).info()['language']
+            try:
+                lang_code = translation(
+                    MESSAGES, LOCALE_DIR).info()['language']
+            except IOError:
+                # Fall back to default.
+                lang_code = 'en'
         path = os.path.join(HELP_DIR, 'help_' + lang_code)
-        if not os.path.isfile(path):
-            lang_code = 'en'
-            path = os.path.join(HELP_DIR, 'help_' + lang_code)
 
         readme_in = codecs.open(path, encoding='utf-8')
         text = readme_in.read()
